@@ -19,6 +19,7 @@ package org.apache.catalina.core;
 import java.io.File;
 import java.io.IOException;
 import java.io.PrintWriter;
+import java.lang.reflect.Method;
 import java.util.Arrays;
 import java.util.HashSet;
 import java.util.Set;
@@ -53,6 +54,7 @@ import org.junit.Assert;
 import org.junit.Test;
 
 import org.apache.catalina.Context;
+import org.apache.catalina.Engine;
 import org.apache.catalina.Host;
 import org.apache.catalina.Lifecycle;
 import org.apache.catalina.LifecycleEvent;
@@ -148,7 +150,7 @@ public class TestStandardContext extends TomcatBaseTest {
 
     private static final class Bug46243Client extends SimpleHttpClient {
 
-        public Bug46243Client(int port) {
+        Bug46243Client(int port) {
             setPort(port);
         }
 
@@ -415,7 +417,7 @@ public class TestStandardContext extends TomcatBaseTest {
         Tomcat tomcat = getTomcatInstance();
 
         // No file system docBase required
-        Context ctx = tomcat.addContext("", null);
+        Context ctx = getProgrammaticRootContext();
 
         // Setup realm
         TesterMapRealm realm = new TesterMapRealm();
@@ -484,7 +486,7 @@ public class TestStandardContext extends TomcatBaseTest {
         Tomcat tomcat = getTomcatInstance();
 
         // No file system docBase required
-        Context ctx = tomcat.addContext("", null);
+        Context ctx = getProgrammaticRootContext();
 
         ctx.setDenyUncoveredHttpMethods(enableDeny);
 
@@ -565,7 +567,7 @@ public class TestStandardContext extends TomcatBaseTest {
         Tomcat tomcat = getTomcatInstance();
 
         // No file system docBase required
-        Context ctx = tomcat.addContext("", null);
+        Context ctx = getProgrammaticRootContext();
 
         // Add ServletContainerInitializer
         Bug51376SCI sci = new Bug51376SCI(loadOnStartUp);
@@ -1056,4 +1058,25 @@ public class TestStandardContext extends TomcatBaseTest {
             resp.getWriter().print("OK");
         }
     }
+
+
+    @Test
+    public void testNamingContextName() throws Exception {
+        Engine engine = new StandardEngine();
+        engine.setName("engine");
+
+        Host host = new StandardHost();
+        host.setName("host");
+        host.setParent(engine);
+
+        Context context = new StandardContext();
+        context.setName("context");
+        context.setParent(host);
+
+        Method m = StandardContext.class.getDeclaredMethod("getNamingContextName");
+        m.setAccessible(true);
+        String result = (String) m.invoke(context);
+
+        Assert.assertEquals("/engine/hostcontext", result);
+    }
 }
